summaryrefslogtreecommitdiff
path: root/src/newgrf_commons.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/newgrf_commons.h')
-rw-r--r--src/newgrf_commons.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/newgrf_commons.h b/src/newgrf_commons.h
index 66ed32404..4441f1258 100644
--- a/src/newgrf_commons.h
+++ b/src/newgrf_commons.h
@@ -101,19 +101,19 @@ TileIndex GetNearbyTile(byte parameter, TileIndex tile);
uint32 GetNearbyTileInformation(TileIndex tile);
/**
* Applies PALETTE_MODIFIER_TRANSPARENT and PALETTE_MODIFIER_COLOR to a palette entry of a sprite layout entry
* @Note for ground sprites use #GroundSpritePaletteTransform
* @Note Not useable for OTTD internal spritelayouts from table/xxx_land.h as PALETTE_MODIFIER_TRANSPARENT is only set
* when to use the default palette.
*
* @param image The sprite to draw
* @param pal The palette from the sprite layout
* @param default_pal The default recolour sprite to use (typically company color resp. random industry/house color)
* @return The palette to use
*/
static inline SpriteID SpriteLayoutPaletteTransform(SpriteID image, SpriteID pal, SpriteID default_pal)
{
- if (HasBit(image, PALETTE_MODIFIER_TRANSPARENT) || HasBit(image, PALETTE_MODIFIER_COLOR)) {
+ if (HasBit(image, PALETTE_MODIFIER_TRANSPARENT) || HasBit(image, PALETTE_MODIFIER_COLOUR)) {
return (pal != 0 ? pal : default_pal);
} else {
return PAL_NONE;
@@ -121,18 +121,18 @@ static inline SpriteID SpriteLayoutPaletteTransform(SpriteID image, SpriteID pal
}
/**
* Applies PALETTE_MODIFIER_COLOR to a palette entry of a ground sprite
* @Note Not useable for OTTD internal spritelayouts from table/xxx_land.h as PALETTE_MODIFIER_TRANSPARENT is only set
* when to use the default palette.
*
* @param image The sprite to draw
* @param pal The palette from the sprite layout
* @param default_pal The default recolour sprite to use (typically company color resp. random industry/house color)
* @return The palette to use
*/
static inline SpriteID GroundSpritePaletteTransform(SpriteID image, SpriteID pal, SpriteID default_pal)
{
- if (HasBit(image, PALETTE_MODIFIER_COLOR)) {
+ if (HasBit(image, PALETTE_MODIFIER_COLOUR)) {
return (pal != 0 ? pal : default_pal);
} else {
return PAL_NONE;
@@ -101,19 +101,19 @@ TileIndex GetNearbyTile(byte parameter, TileIndex tile);
uint32 GetNearbyTileInformation(TileIndex tile);
/**
- * Applies PALETTE_MODIFIER_TRANSPARENT and PALETTE_MODIFIER_COLOR to a palette entry of a sprite layout entry
+ * Applies PALETTE_MODIFIER_TRANSPARENT and PALETTE_MODIFIER_COLOUR to a palette entry of a sprite layout entry
* @Note for ground sprites use #GroundSpritePaletteTransform
* @Note Not useable for OTTD internal spritelayouts from table/xxx_land.h as PALETTE_MODIFIER_TRANSPARENT is only set
@@ -101,19 +101,19 @@ TileIndex GetNearbyTile(byte parameter, TileIndex tile);
* @param image The sprite to draw
* @param pal The palette from the sprite layout
- * @param default_pal The default recolour sprite to use (typically company color resp. random industry/house color)
+ * @param default_pal The default recolour sprite to use (typically company colour resp. random industry/house colour)
* @return The palette to use
*/
@@ -121,18 +121,18 @@ static inline SpriteID SpriteLayoutPaletteTransform(SpriteID image, SpriteID pal
}
/**
- * Applies PALETTE_MODIFIER_COLOR to a palette entry of a ground sprite
+ * Applies PALETTE_MODIFIER_COLOUR to a palette entry of a ground sprite
* @Note Not useable for OTTD internal spritelayouts from table/xxx_land.h as PALETTE_MODIFIER_TRANSPARENT is only set
* when to use the default palette.
@@ -121,18 +121,18 @@ static inline SpriteID SpriteLayoutPaletteTransform(SpriteID image, SpriteID pal
* @param image The sprite to draw
* @param pal The palette from the sprite layout
- * @param default_pal The default recolour sprite to use (typically company color resp. random industry/house color)
+ * @param default_pal The default recolour sprite to use (typically company colour resp. random industry/house colour)
* @return The palette to use
*/